@@ -16,7 +16,7 @@ our @EXPORT_OK = qw(
     is_hash     every    noop        identity
 );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -454,9 +454,10 @@ The iteratee is invoked with three arguments:
 
     maps(sub {
         my $num = shift;
+        return $num + 1;
     }, [1,1,1]);
 
-    # 3
+    # [2,2,2]
 
 =cut
 
